# netbox-qr
A netbox plugin for generating qr codes for specific pages.

This plugin uses [Segno](https://github.com/heuer/segno/).


## Options
- Print with Text
- Print tiwhout Text
- Print Multiple QR Codes (for multiple devices/cables/...)
- Different sizes
- Logo in QR Code
- Text in QR Code
- Font Type

